@@ -4,9 +4,8 @@ from os import path as osp
 
 from basicsr.data import build_dataloader, build_dataset
 from basicsr.models import build_model
-from basicsr.train import parse_options
 from basicsr.utils import get_env_info, get_root_logger, get_time_str, make_exp_dirs
-from basicsr.utils.options import dict2str
+from basicsr.utils.options import dict2str, parse_options
 
 
 def test_pipeline(root_path):
