@@ -4,6 +4,8 @@ import time
 
 from .dist_util import get_dist_info, master_only
 
+initialized_logger = {}
+
 
 class MessageLogger():
     """Message logger for printing.
@@ -123,20 +125,25 @@ def get_root_logger(logger_name='basicsr', log_level=logging.INFO, log_file=None
     """
     logger = logging.getLogger(logger_name)
     # if the logger has been initialized, just return it
-    if logger.hasHandlers():
+    if logger_name in initialized_logger:
         return logger
 
     format_str = '%(asctime)s %(levelname)s: %(message)s'
-    logging.basicConfig(format=format_str, level=log_level)
+    stream_handler = logging.StreamHandler()
+    stream_handler.setFormatter(logging.Formatter(format_str))
+    logger.addHandler(stream_handler)
+    logger.propagate = False
     rank, _ = get_dist_info()
     if rank != 0:
         logger.setLevel('ERROR')
     elif log_file is not None:
+        logger.setLevel(log_level)
+        # add file handler
         file_handler = logging.FileHandler(log_file, 'w')
         file_handler.setFormatter(logging.Formatter(format_str))
         file_handler.setLevel(log_level)
         logger.addHandler(file_handler)
-
+    initialized_logger[logger_name] = True
     return logger
 
 
